pub struct UpdateScript<'a> {
pub project_id: &'a str,
pub script_id: &'a str,
pub script: &'a str,
pub silent: Option<bool>,
pub ffa: Option<bool>,
pub heartbeat: Option<bool>,
pub lightning: Option<bool>,
}Expand description
Programmatically edit a script.
⚠️ Authenticated ⚠️
View full response at [UpdateScriptResponse].
Fields
project_id: &'a strThe associated project ID that contains the script.
script_id: &'a strThe id of the script to update.
script: &'a strThe raw Lua source code to upload.
silent: Option<bool>Disables Luarmor console outputs. This is not recommended as it’s useful for debugging. However, it may be necessary to bypass anti cheats that detect console outputs.
ffa: Option<bool>Free-For-All (FFA) mode allows anyone to execute the script, without a script key. Use with caution, you may not want this behaviour.
heartbeat: Option<bool>Ensures clients are connected via a heartbeat. This is recommended as it improves security. However, in some cases, it may be mandatory if you require instance limits or tracking.
lightning: Option<bool>Removes some inline security checks to make your script run faster. This is not recommended as it decreases the security a little, and optimising your script is preferred.
Implementations
Sourceimpl<'a> UpdateScript<'a>
impl<'a> UpdateScript<'a>
Sourcepub fn builder() -> UpdateScriptBuilder<'a, ((), (), (), (), (), (), ())>
pub fn builder() -> UpdateScriptBuilder<'a, ((), (), (), (), (), (), ())>
Create a builder for building UpdateScript.
On the builder, call .project_id(...), .script_id(...), .script(...), .silent(...)(optional), .ffa(...)(optional), .heartbeat(...)(optional), .lightning(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of UpdateScript.