pub struct UpdateUser<'a> {
pub project_id: &'a str,
pub user_key: &'a str,
pub identifier: Option<&'a str>,
pub auth_expire: Option<OffsetDateTime>,
pub note: Option<&'a str>,
pub discord_id: Option<&'a str>,
}Expand description
Fields
project_id: &'a strThe associated project ID that contains the key.
user_key: &'a strThe user key to update.
identifier: Option<&'a str>A unique identifier for the key, usually their HWID.
auth_expire: Option<OffsetDateTime>The unix timestamp of when the key should expire.
NOTE: if this is not defined, the key will never expire; read the struct comments for more information.
note: Option<&'a str>A custom note for the key, which can be used to identify the user and key or provide additional information about them.
discord_id: Option<&'a str>The Discord ID associated with the key. However if you set up the Discord bot, the user can manually redeem their key and link it via the “Redeem” button on the panel.
NOTE: if a Discord ID is not associated with a key, the user cannot use the /resethwid discord command.
Implementations
Sourceimpl<'a> UpdateUser<'a>
impl<'a> UpdateUser<'a>
Sourcepub fn builder() -> UpdateUserBuilder<'a, ((), (), (), (), (), ())>
pub fn builder() -> UpdateUserBuilder<'a, ((), (), (), (), (), ())>
Create a builder for building UpdateUser.
On the builder, call .project_id(...), .user_key(...), .identifier(...)(optional), .auth_expire(...)(optional), .note(...)(optional), .discord_id(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of UpdateUser.